==> mint-fm2_2.11.tar.gz: mint-fm2-2.9/usr/lib/linuxmint/mint-fm2/endsession/endsession.py <==
#!/usr/bin/env python

# MintDesktop
#	No Copyright (What for?) 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; Version 2
# of the License.

try:
	import os
	import commands
	import sys
	import string
	import pygtk
	pygtk.require("2.0")
except Exception, detail:
	print detail
	pass
try:
	import gtk
	import gtk.glade
	import gettext
except Exception, detail:
	print detail
	sys.exit(1)


# i18n
gettext.install("messages", "/usr/lib/linuxmint/endsession/locale") 

class Quit:
	"""Quit"""

	def __init__(self):
		# vars
		self.gladefile = '/usr/lib/linuxmint/mint-fm2/endsession/endsession.glade'

		self.appName = "Quit"
		self.appVersion = "0.1"
		
		gtk.glade.bindtextdomain(APPDOMAIN, LANGDIR)
		gtk.glade.textdomain(APPDOMAIN)

		# setup glade widget tree
		self.wTree = gtk.glade.XML(self.gladefile, domain='Quit') 
		
		self.wTree.get_widget("main_window").set_title(self.appName)
		# create signal dictionary and connect
		
		self.wTree.get_widget("main_window").connect("destroy", self.restore_splash, "endapp")
		self.wTree.get_widget("button7").connect("clicked", self.restore_splash, "endapp")
		self.wTree.get_widget("button1").connect("clicked", self.restore_splash, "Logout")

#		self.wTree.get_widget("button2").connect("clicked", self.restore_splash, "Switch User")

		self.wTree.get_widget("button3").connect("clicked", self.restore_splash, "Suspend")

		self.wTree.get_widget("button4").connect("clicked", self.restore_splash, "Hibernate")

		self.wTree.get_widget("button5").connect("clicked", self.restore_splash, "Reboot")

		self.wTree.get_widget("button6").connect("clicked", self.restore_splash, "Shutdown")

		# i18n		
		self.wTree.get_widget("label0").set_label(_("<big><b>What Do you Want to do?</b></big>"))
		
		self.wTree.get_widget("label1").set_label(_("Logout"))

#		self.wTree.get_widget("label4").set_label(_("Switch User"))
		
	        self.wTree.get_widget("label2").set_label(_("Suspend"))

		self.wTree.get_widget("label5").set_label(_("Hibernate"))
		
		self.wTree.get_widget("label3").set_label(_("Reboot"))

		self.wTree.get_widget("label6").set_label(_("Shutdown"))

				
	def restore_splash(self, widget, application):				
		if (application == "Logout"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("kill -TERM $(xprop -root _BLACKBOX_PID | awk '{print $3}')")
			gtk.main_quit()		
			sys.exit(0) 
		if (application == "Switch User"):
			os.system("gdmflexiserver") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Suspend"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/suspend") 
			os.system("touch /etc/ciao-trigger/suspend") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Hibernate"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/hibernate") 
			os.system("touch /etc/ciao-trigger/hibernate") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Reboot"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/restart")
			os.system("touch /etc/ciao-trigger/restart") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Shutdown"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/shutdown")
			os.system("touch /etc/ciao-trigger/shutdown")
			gtk.main_quit()		
			sys.exit(0) 
		if (application == "endapp"):
			gtk.main_quit()		
			sys.exit(0)	


		
# ---------- MAIN ----------

if __name__ == "__main__":
	APPDOMAIN='Quit'
	LANGDIR='lang'
	# locale
	gtk.glade.bindtextdomain(APPDOMAIN, LANGDIR)
	gtk.glade.textdomain(APPDOMAIN)
	rec = Quit()
	# run gui
	gtk.main()

==> mint-fm2_3.25.tar.gz: mint-fm2-3.25/usr/lib/linuxmint/mint-fm2/endsession/endsession.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# MintDesktop
#	No Copyright (What for?) 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; Version 2
# of the License.

try:
	import os
	import commands
	import sys
	import string
	import pygtk
	pygtk.require("2.0")
except Exception, detail:
	print detail
	pass
try:
	import gtk
	import gtk.glade
	import gettext
except Exception, detail:
	print detail
	sys.exit(1)


# i18n
gettext.install("messages", "/usr/lib/linuxmint/mint-fm2/endsession/locale") 

class Quit:
	"""Quit"""

	def __init__(self):
		# vars
		self.gladefile = '/usr/lib/linuxmint/mint-fm2/endsession/endsession.glade'

		self.appName = "Quit"
		self.appVersion = "0.1"
		
		gtk.glade.bindtextdomain(APPDOMAIN, LANGDIR)
		gtk.glade.textdomain(APPDOMAIN)

		# setup glade widget tree
		self.wTree = gtk.glade.XML(self.gladefile, domain='Quit') 
		
		self.wTree.get_widget("main_window").set_title(self.appName)
		# create signal dictionary and connect
		
		self.wTree.get_widget("main_window").connect("destroy", self.restore_splash, "endapp")
		self.wTree.get_widget("button7").connect("clicked", self.restore_splash, "endapp")
		self.wTree.get_widget("button1").connect("clicked", self.restore_splash, "Logout")

#		self.wTree.get_widget("button2").connect("clicked", self.restore_splash, "Switch User")

		self.wTree.get_widget("button3").connect("clicked", self.restore_splash, "Suspend")

		self.wTree.get_widget("button4").connect("clicked", self.restore_splash, "Hibernate")

		self.wTree.get_widget("button5").connect("clicked", self.restore_splash, "Reboot")

		self.wTree.get_widget("button6").connect("clicked", self.restore_splash, "Shutdown")

		# i18n		
		self.wTree.get_widget("label0").set_label(_("<big><b>What Do you Want to do?</b></big>"))
		
		self.wTree.get_widget("label1").set_label(_("Logout"))

#		self.wTree.get_widget("label4").set_label(_("Switch User"))
		
	        self.wTree.get_widget("label2").set_label(_("Suspend"))

		self.wTree.get_widget("label5").set_label(_("Hibernate"))
		
		self.wTree.get_widget("label3").set_label(_("Reboot"))

		self.wTree.get_widget("label6").set_label(_("Shutdown"))

				
	def restore_splash(self, widget, application):				
		if (application == "Logout"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("kill -TERM $(xprop -root _BLACKBOX_PID | awk '{print $3}')")
			gtk.main_quit()		
			sys.exit(0) 
		if (application == "Switch User"):
			os.system("gdmflexiserver") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Suspend"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/suspend") 
			os.system("touch /etc/ciao-trigger/suspend") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Hibernate"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/hibernate") 
			os.system("touch /etc/ciao-trigger/hibernate") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Reboot"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/restart")
			os.system("touch /etc/ciao-trigger/restart") 
			gtk.main_quit()		
			sys.exit(0)
		if (application == "Shutdown"):
			os.system("cd /usr/lib/linuxmint/mint-fm2 && ./sound logout &> /dev/null")
			os.system("rm /etc/ciao-trigger/shutdown")
			os.system("touch /etc/ciao-trigger/shutdown")
			gtk.main_quit()		
			sys.exit(0) 
		if (application == "endapp"):
			gtk.main_quit()		
			sys.exit(0)	


		
# ---------- MAIN ----------

if __name__ == "__main__":
	APPDOMAIN='Quit'
	LANGDIR='lang'
	# locale
	gtk.glade.bindtextdomain(APPDOMAIN, LANGDIR)
	gtk.glade.textdomain(APPDOMAIN)
	rec = Quit()
	# run gui
	gtk.main()
